@@ -60,6 +60,11 @@ makeLinkedTxome(
 # pull down the TxDb from AnnotationHub, alterantively
 # once can specify useHub=FALSE.
 
+## -----------------------------------------------------------------------------
+coldata <- coldata[coldata$condition %in% c("naive","IFNg"),]
+coldata$condition <- factor(coldata$condition, 
+                            levels=c("naive","IFNg"))
+
 ## -----------------------------------------------------------------------------
 library(tximeta)
 se <- tximeta(coldata)
@@ -79,10 +84,6 @@ metadata(se)$txomeInfo$source <- "GENCODE"
 y <- se
 y <- y[seqnames(y) == "chr4",]
 
-## -----------------------------------------------------------------------------
-y <- y[,y$condition %in% c("naive","IFNg")]
-y$condition <- factor(y$condition, levels=c("naive","IFNg"))
-
 ## ----results="hide", message=FALSE--------------------------------------------
 library(fishpond)
 y <- scaleInfReps(y)
@@ -91,6 +92,11 @@ y <- y[mcols(y)$keep,]
 set.seed(1)
 y <- swish(y, x="condition", pair="line")
 
+## -----------------------------------------------------------------------------
+y_fast <- swish(y, x="condition", pair="line", fast=1)
+table(original=mcols(y)$qvalue < .1,
+      fast=mcols(y_fast)$qvalue < .1)
+
 ## -----------------------------------------------------------------------------
 table(mcols(y)$qvalue < .05)
 
@@ -143,10 +149,6 @@ gse <- summarizeToGene(se)
 gy <- gse
 gy <- gy[seqnames(gy) == "chr4",]
 
-## -----------------------------------------------------------------------------
-gy <- gy[,gy$condition %in% c("naive","IFNg")]
-gy$condition <- factor(gy$condition, c("naive","IFNg"))
-
 ## ----results="hide", message=FALSE--------------------------------------------
 gy <- scaleInfReps(gy)
 gy <- labelKeep(gy)
@@ -197,27 +199,12 @@ with(
 iso <- isoformProportions(y)
 iso <- swish(iso, x="condition", pair="line")
 
-## ----eval=FALSE, echo=FALSE---------------------------------------------------
-#  # some unevaluated code for looking into DTE within non-DGE gene
-#  # (DTE vs DGE plot)
-#  fisherP <- function(p) {
-#    pchisq(-2 * sum(log(p)), 2*length(p), lower.tail=FALSE)
-#  }
-#  stopifnot(all(lengths(mcols(y)$gene_id) == 1))
-#  dat <- as.data.frame(mcols(y)[,c("gene_id","pvalue")])
-#  dat$gene_id <- unlist(dat$gene_id)
-#  pvals <- tapply(dat$pvalue, dat$gene_id, fisherP)
-#  dte <- data.frame(gene_id=names(pvals), pvalue=pvals)
-#  dte <- dte[rownames(gy),]
-#  plot(-log10(mcols(gy)$pvalue), -log10(dte$pvalue))
-#  #identify(-log10(mcols(gy)$pvalue), -log10(dte$pvalue))
-#  idx <- 193
-#  idx2 <- which(unlist(mcols(y)$gene_id) == rownames(gy)[idx])
-#  plotInfReps(gy, idx, x="condition", cov="line", xaxis=FALSE)
-#  par(mfrow=c(1,3))
-#  for (i in 1:3) {
-#    plotInfReps(y, idx2[i], x="condition", cov="line", xaxis=FALSE)
-#  }
+## -----------------------------------------------------------------------------
+coldata <- read.csv(file.path(dir, "coldata.csv"))
+coldata <- coldata[,c(1,2,3,5)]
+names(coldata) <- c("names","id","line","condition")
+coldata$files <- file.path(dir, "quants", coldata$names, "quant.sf.gz")
+se <- tximeta(coldata)
 
 ## -----------------------------------------------------------------------------
 se$ifng <- factor(ifelse(
@@ -227,20 +214,21 @@ se$salmonella <- factor(ifelse(
   grepl("SL1344",se$condition),
   "infected","control"))
 with(colData(se),
-     table(ifng, salmonella)
-     )
+     table(ifng, salmonella))
 
 ## -----------------------------------------------------------------------------
 y2 <- se
 y2 <- y2[seqnames(y2) == "chr1",]
 
 ## -----------------------------------------------------------------------------
-y2$pair <- as.numeric(factor(y2$line))
+y2$pair <- factor(y2$line)
+levels(y2$pair) <- LETTERS[1:6] # simplify names
+y2$pair <- as.character(y2$pair)
 y2$pair[y2$ifng == "control"]
 y2$pair[y2$ifng == "treated"]
-y2$pair[y2$ifng == "treated"] <- rep(7:12,each=2)
+y2$pair[y2$ifng == "treated"] <- rep(LETTERS[7:12], each=2)
 y2$pair <- factor(y2$pair)
-table(y2$pair, y2$salmonella)
+head(table(y2$pair, y2$salmonella))
 
 ## ----results="hide", message=FALSE--------------------------------------------
 y2 <- scaleInfReps(y2)
@@ -260,6 +248,9 @@ idx <- with(mcols(y2), which(qvalue < .05 & log2FC > 5))
 plotInfReps(y2, idx[1], x="ifng", cov="salmonella")
 plotInfReps(y2, idx[2], x="ifng", cov="salmonella")
 
+## ----eval=FALSE---------------------------------------------------------------
+#  vignette(topic="allelic", package="fishpond")
+
 ## ----eval=FALSE---------------------------------------------------------------
 #  dir <- system.file("extdata", package="tximportData")
 #  files <- file.path(dir,"alevin/neurons_900_v014/alevin/quants_mat.gz")
@@ -299,16 +290,11 @@ plotInfReps(y2, idx[2], x="ifng", cov="salmonella")
 #  library(SingleCellExperiment)
 #  y <- as(y, "SingleCellExperiment")
 #  # then, after filtering genes and cells...
-#  
 #  # compute and store sizeFactors calculated over all genes
-#  library(scran)
-#  y <- computeSumFactors(y)
-#  
+#  y <- scran::computeSumFactors(y)
 #  # split swish objects into 8 RDS files:
 #  splitSwish(y, nsplits=8, prefix="swish", snakefile="Snakefile")
-#  
 #  # now, run snakemake from command line
-#  
 #  # after finished, results back into R:
 #  y <- addStatsFromCSV(y, "summary.csv")
 
